<img src="https://www.kubeflow.org/images/logo.svg" width="100">

## Overview of Kubeflow Fairing

Kubeflow Fairing is a Python package that streamlines the process of building,
training, and deploying machine learning (ML) models in a hybrid cloud
environment. By using Kubeflow Fairing and adding a few lines of code, you can
run your ML training job locally or in the cloud, directly from Python code or
a Jupyter notebook. After your training job is complete, you can use Kubeflow
Fairing to deploy your trained model as a prediction endpoint.

## Documentation

To learn how Kubeflow Fairing streamlines the process of training and deploying
ML models in the cloud, read the [Kubeflow Fairing
documentation][fairing-overview]. 

To learn the details of Kubeflow Fairing API, read the
[markdown documentation][markdown-doc] or [HTML documentation][html-doc]
via `htmlpreview.github.io`.

[fairing-overview]: https://www.kubeflow.org/docs/fairing/fairing-overview/
[markdown-doc]: https://github.com/kubeflow/fairing/tree/master/docs/markdown
[html-doc]: http://htmlpreview.github.io/?https://github.com/kubeflow/fairing/blob/master/docs/html/kubeflow.fairing.html